baal library

Classes

AudioPlayerStyle
AudioRecorderStyle
BaalDebuger
BaalEnsureInitialized
OwlnextAudioPlayer
OwlnextAudioRecorder
OwlnextPlayerController
This controller is used to play audio files You can instantiate this class with the initialize method
OwlnextRecorderController
This controller is used to setup audio recordings You can instantiate this class with the initialize method

Enums

PlayerState
RecordState
All states of the recorder
SourceType